.. _netapi-client:

============
NetapiClient
============

The :py:class:`NetapiClient` class provides access to
:ref:`Python API client interfaces <client-interfaces>` when
:ref:`developing netapi modules <netapi-writing>`

.. autoclass:: salt.netapi.NetapiClient
    :members:  local, local_async, local_subset, ssh, runner, runner_async,
        wheel, wheel_async, run
